﻿using HeuristicLab.Clients.Access.Administration;
using HeuristicLab.Clients.Hive.WebJobManager.Controllers;
using HeuristicLab.Clients.Hive.WebJobManager.Services;
using HeuristicLab.Clients.Hive.WebJobManager.ViewModels.User;
using Microsoft.AspNet.SignalR;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace HeuristicLab.Clients.Hive.WebJobManager.Hubs
{
    /// <summary>
    /// Small SignalR hub to change the password from a user
    /// </summary>
    public class UserInfoHub: Hub
    {
        private WebLoginService weblog;
        private Guid userId;
        private AccessAdministrationClient aac;
        /// <summary>
        /// Loads required services
        /// </summary>
        private void loader()
        {
            weblog = WebLoginService.Instance;
            string uid = Context.QueryString["userid"];
            if (uid == null || uid == "" || Guid.Parse(uid) == Guid.Empty)
            {
                userId = Guid.Empty;
            }
            else
            {
                userId = Guid.Parse(uid);
                aac = weblog.getAccessAdminClient(userId);
            }
        }
        /// <summary>
        /// Request to change pass 
        /// </summary>
        /// <param name="user">User id</param>
        public void resetPassword(string user)
        {
            loader();
            Guid userid = Guid.Parse(user);
            Access.User u = new UserViewModel(aac, weblog.getCurrentUser(userId)).refreshUsers().getUserById(userid);
            var pass = aac.resetPassword(userid);
            UserController.sendPassmail(u, pass);//Send mail + show pass            
            Clients.Caller.showNewPass(pass);
        }
    }
}
